﻿using System;
using System.Collections;
using System.Configuration;
using System.Data;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;

namespace BlackTieMedical
{
    public partial class Controls_DataPageNavigation : System.Web.UI.UserControl
    {
        private Delegate m_dRefreshParentGrid;
        private Delegate m_dUpdateCurrentPage;
        private PagedDataSource m_pdsPagedData;
        private string m_strSearchArgs;

        #region Properties

        public int CurrentPage
        {
            get
            {
                object o = ViewState["CurrentPage"];
                if (o == null)
                    return 0;
                else
                    return (int)o;
            }

            set
            {
                ViewState["CurrentPage"] = value;
            }
        }

        public int LastPage
        {
            get
            {
                object o = ViewState["LastPage"];
                if (o == null)
                    return 0;
                else
                    return (int)o;
            }

            set
            {
                ViewState["LastPage"] = value;
            }
        }

        public Delegate RefreshParentGrid
        {
            get { return m_dRefreshParentGrid; }
            set { m_dRefreshParentGrid = value; }
        }

        public Delegate UpdateCurrentPage
        {
            get { return m_dUpdateCurrentPage; }
            set { m_dUpdateCurrentPage = value; }
        }

        public PagedDataSource PagedData
        {
            get { return m_pdsPagedData; }
            set { m_pdsPagedData = value; }
        }

        public string SearchArgs
        {
            get { return m_strSearchArgs; }
            set { m_strSearchArgs = value; }
        }

        #endregion

        protected Controls_DataPageNavigation()
        {
            PagedData = new PagedDataSource();
        }

        ///
        /// these setup functions will handle the data setup
        /// 
        public void SetupDataPageNavigation(DataView dvDataSource)
        {
            PagedData = new PagedDataSource();
            SetupDataPageNavigation(dvDataSource, true, 100);
        }

        public void SetupDataPageNavigation(DataView dvDataSource, bool bAllowPaging)
        {
            PagedData = new PagedDataSource();
            SetupDataPageNavigation(dvDataSource, bAllowPaging, 100);
        }

        public void SetupDataPageNavigation(DataView dvDataSource, bool bAllowPaging, int iPageSize)
        {
            PagedData.DataSource = dvDataSource;
            PagedData.AllowPaging = true;
            PagedData.PageSize = iPageSize;
            PagedData.CurrentPageIndex = CurrentPage;
            
            lblPageCount.Text = "Page: " + (CurrentPage + 1) + " of " + PagedData.PageCount;
            txtPage.Text = (CurrentPage + 1).ToString();

            LastPage = PagedData.PageCount - 1;
        }

        protected void btnImagePrev_OnClick(object sender, ImageClickEventArgs e)
        {
            if (CurrentPage > 0)
            {
                CurrentPage -= 1;

                UpdateCurrentPage.DynamicInvoke(CurrentPage);
                RefreshParentGrid.DynamicInvoke(SearchArgs);
            }
        }

        ///
        /// these functions take care of the actual paging and page display
        ///
        protected void btnImageNext_OnClick(object sender, ImageClickEventArgs e)
        {
            if (CurrentPage < LastPage)
            {
                CurrentPage += 1;

                UpdateCurrentPage.DynamicInvoke(CurrentPage);
                RefreshParentGrid.DynamicInvoke(SearchArgs);
            }
        }

        protected void btnImageFirst_OnClick(object sender, ImageClickEventArgs e)
        {
            if (CurrentPage != 0)
            {
                CurrentPage = 0;

                UpdateCurrentPage.DynamicInvoke(CurrentPage);
                RefreshParentGrid.DynamicInvoke(SearchArgs);
            }
        }

        protected void btnImageLast_OnClick(object sender, ImageClickEventArgs e)
        {
            if (CurrentPage != LastPage)
            {
                CurrentPage = LastPage;

                UpdateCurrentPage.DynamicInvoke(CurrentPage);
                RefreshParentGrid.DynamicInvoke(SearchArgs);
            }
        }

        protected void GotoPageNumberChanged(object sender, EventArgs e)
        {
            int iPageNumber = 1;
            
            if (txtPage.Text.Length > 3)
                return;

            if (!(int.TryParse(txtPage.Text, out iPageNumber)))
                return;

            iPageNumber--; // Subtract one to adjust for zero index

            if (iPageNumber >= 0 && iPageNumber <= LastPage)
            {
                UpdateCurrentPage.DynamicInvoke(iPageNumber);
                RefreshParentGrid.DynamicInvoke(SearchArgs);
                txtPage.Text = (CurrentPage + 1).ToString();
            }
        }

        protected void btnImageGotoPage_OnClick(object sender, ImageClickEventArgs e)
        {
            GotoPageNumberChanged(null, null);
        }

        //protected void UpdatePageCountDisplay()
        //{
        //    lblPageCount.Text = "Page: " + (CurrentPage + 1).ToString() + " of "
        //        + PagedData.PageCount.ToString();
        //}
    }
}